<?php

namespace Fastrack\Utilities;

use Psr\Container\NotFoundExceptionInterface;
use Psr\SimpleCache\CacheInterface;
use Psr\SimpleCache\InvalidArgumentException;
use SilverStripe\Control\Controller;
use SilverStripe\Control\Director;
use SilverStripe\Control\HTTPResponse;
use SilverStripe\Core\Injector\Injector;
use SilverStripe\Security\Security;

class Api
{

	public static function constructResponse(Controller $controller, array $data): HTTPResponse
	{
		$controller->getResponse()->setBody(json_encode($data));
		$controller->getResponse()->addHeader("Content-type", "application/json");
		return $controller->getResponse();
	}


	public static function fetchFromCache($key, $default)
	{
		if (!Api::shouldCache()) return $default;
		try {
			return Api::getCache()->get($key, $default);
		} catch (NotFoundExceptionInterface|InvalidArgumentException $e) {
			return $default;
		}
	}

	public static function setCache(string $key, $value) {
		if (!Api::shouldCache()) return;
		try {
			Api::getCache()->set($key, $value, 60 * 60 * 6);
		} catch (NotFoundExceptionInterface|InvalidArgumentException $e) {
			user_error($e->getMessage(), E_USER_WARNING);
		}
	}

	/**
	 * @throws NotFoundExceptionInterface
	 */
	public static function getCache(): CacheInterface
	{
		return Injector::inst()->get(CacheInterface::class . '.fastrackApiCache');
	}

	public static function shouldCache(): bool
	{
		if (Security::getCurrentUser()) {
			return false;
		}
		if (Director::isDev()) {
			return false;
		}
		return true;
	}

}
